Module computed

Module computed 

Computed reactive values that derive from other reactive values.

Modules

suspense
Utilities used to track whether asynchronous computeds are currently loading.

Structs

ArcAsyncDerived
A reactive value that is derived by running an asynchronous computation in response to changes in its sources.
ArcMemo
An efficient derived reactive value based on other reactive values.
AsyncDerived
A reactive value that is derived by running an asynchronous computation in response to changes in its sources.
AsyncDerivedFuture
A Future that is ready when an ArcAsyncDerived is finished loading or reloading, and contains its value. .awaiting this clones the value T.
AsyncDerivedReadyFuture
A Future that is ready when an ArcAsyncDerived is finished loading or reloading, but does not contain its value.
AsyncDerivedRefFuture
A Future that is ready when an ArcAsyncDerived is finished loading or reloading, and yields an AsyncDerivedGuard that dereferences to its value.
Memo
A memo is an efficient derived reactive value based on other reactive values.
ScopedFuture
A Future wrapper that sets the Owner and Observer before polling the inner Future.
ScopedFutureUntrackedWithDiagnostics
A Future wrapper that sets the Owner and Observer before polling the inner Future, output of ScopedFuture::new_untracked_with_diagnostics.
Selector
A conditional signal that only notifies subscribers when a change in the source signal’s value changes whether the given function is true.

Functions

create_memoDeprecated
Creates a new memoized, computed reactive value.
create_owning_memoDeprecated
Creates a new memo by passing a function that computes the value.
create_read_slice
Takes a memoized, read-only slice of a signal. This is equivalent to the read-only half of create_slice.
create_selectorDeprecated
A conditional signal that only notifies subscribers when a change in the source signal’s value changes whether the given function is true.
create_selector_with_fnDeprecated
Creates a conditional signal that only notifies subscribers when a change in the source signal’s value changes whether the given function is true.
create_slice
Derives a reactive slice of an RwSignal.
create_write_slice
Creates a setter to access one slice of a signal. This is equivalent to the write-only half of create_slice.

Type Aliases

AsyncDerivedGuard
A read guard that holds access to an async derived resource.