Module graph

Module graph 

Types that define the reactive graph itself. These are mostly internal, but can be used to create custom reactive primitives.

Structs

AnySource
A weak reference to any reactive source node.
AnySubscriber
A type-erased subscriber.
Observer
The current reactive observer.

Enums

ReactiveNodeState
The current state of a reactive node.

Traits

ReactiveNode
A node in the reactive graph.
Describes the behavior of any source of reactivity (like a signal, trigger, or memo.)
Subscriber
Any type that can track reactive values (like an effect or a memo).
ToAnySource
Abstracts over the type of any reactive source.
ToAnySubscriber
Converts a Subscriber to a type-erased AnySubscriber.
WithObserver
Runs code with some subscriber as the thread-local Observer.

Functions

untrack
Suspends reactive tracking while running the given function.