Module send_wrapper_ext

Module send_wrapper_ext 

Additional wrapper utilities for send_wrapper::SendWrapper.

Structs

SendOption
An optional value that can always be sent between threads, even if its inner value in the Some(_) case would not be threadsafe.